==> examples-4.7.5-src.tar.gz: openejb-examples-4.7.5/deltaspike-fullstack/src/main/java/org/superbiz/deltaspike/domain/validation/UserName.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.superbiz.deltaspike.domain.validation;

import javax.validation.Constraint;
import javax.validation.Payload;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import javax.validation.groups.Default;
import java.lang.annotation.Retention;
import java.lang.annotation.Target;

import static java.lang.annotation.ElementType.FIELD;
import static java.lang.annotation.RetentionPolicy.RUNTIME;

@NotNull(groups = Default.class)
@Size(min = 2, max = 9, message = "invalid name", groups = Default.class)

@Constraint(validatedBy = UniqueUserNameValidator.class)
@Target(FIELD)
@Retention(RUNTIME)
public @interface UserName
{
    String message() default "user-name exists already";

    Class<?>[] groups() default {};

    Class<? extends Payload>[] payload() default {};
}

==> examples-7.1.4-src.tar.gz: openejb-examples-7.1.4/deltaspike-fullstack/src/main/java/org/superbiz/deltaspike/domain/validation/UserName.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.superbiz.deltaspike.domain.validation;

import javax.validation.Constraint;
import javax.validation.Payload;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import javax.validation.groups.Default;
import java.lang.annotation.Retention;
import java.lang.annotation.Target;

import static java.lang.annotation.ElementType.FIELD;
import static java.lang.annotation.RetentionPolicy.RUNTIME;

@NotNull(groups = Default.class)
@Size(min = 2, max = 9, message = "invalid name", groups = Default.class)

@Constraint(validatedBy = UniqueUserNameValidator.class)
@Target(FIELD)
@Retention(RUNTIME)
public @interface UserName {
    String message() default "user-name exists already";

    Class<?>[] groups() default {};

    Class<? extends Payload>[] payload() default {};
}
